/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.fleet.machine.tree;

import java.util.List;
import nl.cloudfarming.client.fleet.model.Machine;
import org.openide.filesystems.*;
import org.openide.loaders.DataObject;
import org.openide.loaders.DataObjectNotFoundException;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Node;
import org.openide.util.Lookup;
import org.openide.util.lookup.Lookups;
import org.openide.util.lookup.ProxyLookup;

/**
 *
 * @author Wytse Visser && Maciek Dulkiewicz
 */
public abstract class MachineCategoryChildFactory extends ChildFactory<FileObject> implements FileChangeListener {

    protected String fileExtension;
    protected FileObject machineDirectory;

    @SuppressWarnings("LeakingThisInConstructor")
    protected MachineCategoryChildFactory(String fileExtension, FileObject machineDirectory) {
        this.fileExtension = fileExtension;
        this.machineDirectory = machineDirectory;
        machineDirectory.addRecursiveListener(this);
    }

    @Override
    protected boolean createKeys(List<FileObject> list) {
        FileObject[] files = machineDirectory.getChildren();
        for (FileObject file : files) {
            if (file.hasExt(fileExtension) && !file.isFolder()) {
                list.add(file);
            }
        }
        return true;
    }

    @Override
    public void fileAttributeChanged(FileAttributeEvent fae) {
        refresh(true);
    }

    @Override
    public void fileChanged(FileEvent fe) {
        refresh(true);
    }

    @Override
    public void fileDataCreated(FileEvent fe) {
        // Don't do anything. fileChanged() will be called automatically when
        // a machine is saved to its file.
    }

    @Override
    public void fileDeleted(FileEvent fe) {
        refresh(true);
    }

    @Override
    public void fileFolderCreated(FileEvent fe) {
        //folders are not used to make children, do nothing
    }

    @Override
    public void fileRenamed(FileRenameEvent fre) {
        refresh(true);
    }

    protected Node getNodeFromDataObject(FileObject fileObject) throws DataObjectNotFoundException {
        if (fileObject == null) {
            throw new NullPointerException();
        }
        return DataObject.find(fileObject).getNodeDelegate();
    }

    public FileObject getMachineDirectory() {
        return machineDirectory;
    }

    protected Lookup createLookup(FileObject fileObject, Machine machine) {
        return new ProxyLookup(machine.getLookup(), Lookups.fixed(fileObject, machine));
    }
}
