/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.fleet.machine.tree;

import java.awt.datatransfer.Transferable;
import java.awt.event.ActionEvent;
import java.util.List;
import javax.swing.AbstractAction;
import nl.cloudfarming.client.fleet.machine.windows.ListOverviewTopComponent;
import nl.cloudfarming.client.fleet.model.Machine;
import nl.cloudfarming.client.geoviewer.SimpleLayer;
import org.openide.filesystems.*;
import org.openide.nodes.AbstractNode;
import org.openide.nodes.Children;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;
import org.openide.util.datatransfer.PasteType;
import org.openide.util.lookup.Lookups;
import org.openide.util.lookup.ProxyLookup;

/**
 *
 * @author Wytse Visser
 */
public abstract class MachineCategoryNode extends AbstractNode {

    private FileObject machineDirectory;

    public MachineCategoryNode(MachineCategoryChildFactory childFactory, Lookup lookup) {
        super(Children.create(childFactory, true), createLookup(lookup));
        this.machineDirectory = childFactory.getMachineDirectory();
    }
    
    private static Lookup createLookup(Lookup lookup) {
        String name = lookup.lookup(MachineMetaInfo.class).getDisplayName();
        return new ProxyLookup(lookup, Lookups.fixed(new SimpleLayer(name)));
    }

    public final MachineMetaInfo getMetaInfo() {
        return getLookup().lookup(MachineMetaInfo.class);
    }

    public abstract List<Machine> getMachines();

    @Override
    public PasteType getDropType(Transferable t, int action, int index) {
        return null;
    }

    @NbBundle.Messages({"fleet.machine.category_node_open_action_name=Open"})
    protected class OpenAction extends AbstractAction {

        public OpenAction() {
            super(Bundle.fleet_machine_category_node_open_action_name());
        }

        @Override
        public void actionPerformed(ActionEvent e) {
            ListOverviewTopComponent overviewComponent = ListOverviewTopComponent.findInstance(getMetaInfo());
            overviewComponent.setMachines(getMachines());
            overviewComponent.open();
            overviewComponent.requestActive();
            machineDirectory.addRecursiveListener(new MachineFileChangeListener(overviewComponent));
        }

        @Override
        public boolean isEnabled() {
            return !getMachines().isEmpty();
        }
    }

    private class MachineFileChangeListener implements FileChangeListener {

        private ListOverviewTopComponent overviewComponent;

        public MachineFileChangeListener(ListOverviewTopComponent overviewComponent) {
            this.overviewComponent = overviewComponent;
        }

        @Override
        public void fileFolderCreated(FileEvent fe) {
            // Don't do anything
        }

        @Override
        public void fileDataCreated(FileEvent fe) {
            // Don't do anything yet. When the machine is saved to the file, 
            // fileChanged will be called automagically.
        }

        @Override
        public void fileChanged(FileEvent fe) {
            refreshOverviewComponent();
        }

        @Override
        public void fileDeleted(FileEvent fe) {
            refreshOverviewComponent();
        }

        @Override
        public void fileRenamed(FileRenameEvent fe) {
            refreshOverviewComponent();
        }

        @Override
        public void fileAttributeChanged(FileAttributeEvent fe) {
            refreshOverviewComponent();
        }

        private void refreshOverviewComponent() {
            overviewComponent.setMachines(getMachines());
        }
    }

    public interface MachineMetaInfo {

        public String getDisplayName();

        public String getSmallIconResource();

        public String getLargeIconResource();
    }
}