/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.fleet.machine.windows;

import java.awt.BorderLayout;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import nl.cloudfarming.client.fleet.machine.tree.MachineCategoryNode.MachineMetaInfo;
import nl.cloudfarming.client.fleet.model.Machine;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.netbeans.api.settings.ConvertAsProperties;
import org.openide.awt.ActionID;
import org.openide.util.ImageUtilities;
import org.openide.windows.TopComponent;

/**
 * This top component shows a list of machines.
 *
 * @author Wytse Visser
 */
@ConvertAsProperties(dtd = "-//nl.cloudfarming.client.fleet.machine.windows//ListOverview//EN",
autostore = false)
@TopComponent.Description(preferredID = "ListOverviewTopComponent",
persistenceType = TopComponent.PERSISTENCE_NEVER)
@TopComponent.Registration(mode = "editor", openAtStartup = false)
@ActionID(category = "Window", id = "nl.cloudfarming.client.fleet.machine.windows.ListOverviewTopComponent")
public class ListOverviewTopComponent extends TopComponent {

    private static Map<MachineMetaInfo, ListOverviewTopComponent> overviewForMachineType = new HashMap<>();
    private ListOverviewPanel panel;
    private ASBodyPanel bodyPanel;

    public ListOverviewTopComponent() {
        setLayout(new BorderLayout());
        panel = new ListOverviewPanel();
        bodyPanel = new ASBodyPanel(panel);
        add(bodyPanel);
    }

    public static ListOverviewTopComponent findInstance(MachineMetaInfo machineInfo) {
        ListOverviewTopComponent overview = overviewForMachineType.get(machineInfo);
        if (overview == null) {
            overview = new ListOverviewTopComponent();
            overview.initTitleLabel(machineInfo.getDisplayName(), machineInfo.getLargeIconResource());
            overview.setName(machineInfo.getDisplayName());
            overview.setToolTipText(machineInfo.getDisplayName());
            overview.initIcon(machineInfo.getSmallIconResource());
            overviewForMachineType.put(machineInfo, overview);
        }
        return overview;
    }

    public void initTitleLabel(String title, String iconResource) {
        bodyPanel.setTitle(title);
        if (iconResource != null) {
            bodyPanel.setIcon(ImageUtilities.loadImageIcon(iconResource, true));
        }
    }

    public void initIcon(String iconResource) {
        if (iconResource != null) {
            setIcon(ImageUtilities.loadImage(iconResource));
        }
    }
    
    @Override
    public void componentOpened() {
    }

    @Override
    public void componentClosed() {
    }

    void writeProperties(java.util.Properties p) {
    }

    void readProperties(java.util.Properties p) {
    }

    public void setMachines(List<Machine> machines) {
        panel.setMachines(machines);
    }
}